==> parodia_admin-1.0.2.tar.gz: lib/core/repository/campaign.repository.dart <==
// POST
// /api/v1/dashboard/campaigns/slugify

// GET
// /api/v1/dashboard/campaigns/{id}

// PUT
// /api/v1/dashboard/campaigns/{id}

// DELETE
// /api/v1/dashboard/campaigns/{id}

// GET
// /api/v1/dashboard/campaigns

// POST
// /api/v1/dashboard/campaigns

// POST
// /api/v1/dashboard/campaigns/{id}/recover

import 'package:parodia_admin/core/dto/campaign.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class CampaignRepository {
  ParodiaHTTP? _http;

  CampaignRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<CampaignDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/campaigns',
      param: id,
    );

    return ResponseItemDTO<CampaignDTO>(
      response: response,
      fromJson: CampaignDTO.fromJson,
    );
  }

  Future<ResponseListDTO<CampaignDTO>> getAll({CampaignQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/campaigns',
      query: query,
    );

    return ResponseListDTO<CampaignDTO>(
      response: response,
      fromJson: CampaignDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({CampaignBody? campaign}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/campaigns',
      data: campaign,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, CampaignBody? campaign}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/campaigns',
      param: id,
      data: campaign,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/campaigns',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/campaigns/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> slugify({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/campaigns/slugify',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}

==> parodia_admin-1.0.20.tar.gz: lib/core/repository/campaign.repository.dart <==
// POST
// /api/v1/dashboard/dashboard/campaigns/slugify

// GET
// /api/v1/dashboard/dashboard/campaigns/{id}

// PUT
// /api/v1/dashboard/dashboard/campaigns/{id}

// DELETE
// /api/v1/dashboard/dashboard/campaigns/{id}

// GET
// /api/v1/dashboard/dashboard/campaigns

// POST
// /api/v1/dashboard/dashboard/campaigns

// POST
// /api/v1/dashboard/dashboard/campaigns/{id}/recover

import 'package:parodia_admin/core/dto/campaign.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class CampaignRepository {
  ParodiaHTTP? _http;

  CampaignRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<CampaignDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/campaigns',
      param: id,
    );

    return ResponseItemDTO<CampaignDTO>(
      response: response,
      fromJson: CampaignDTO.fromJson,
    );
  }

  Future<ResponseListDTO<CampaignDTO>> getAll({CampaignQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/campaigns',
      query: query,
    );

    return ResponseListDTO<CampaignDTO>(
      response: response,
      fromJson: CampaignDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({CampaignBody? campaign}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/campaigns',
      data: campaign,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, CampaignBody? campaign}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/campaigns',
      param: id,
      data: campaign,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/campaigns',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/campaigns/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> slugify({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/campaigns/slugify',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
